@@ -1,11 +1,12 @@
 """Postgres database implementation."""
-from typing import List
+from typing import Dict, List
 
 import pandas as pd
 import sqlalchemy
 from airflow.providers.postgres.hooks.postgres import PostgresHook
+from psycopg2 import sql as postgres_sql
 
-from astro.constants import DEFAULT_CHUNK_SIZE, LoadExistStrategy
+from astro.constants import DEFAULT_CHUNK_SIZE, LoadExistStrategy, MergeConflictStrategy
 from astro.databases.base import BaseDatabase
 from astro.settings import SCHEMA
 from astro.sql.table import Metadata, Table
@@ -26,7 +27,11 @@ class PostgresDatabase(BaseDatabase):
         super().__init__(conn_id)
 
     @property
-    def hook(self):
+    def sql_type(self) -> str:
+        return "postgresql"
+
+    @property
+    def hook(self) -> PostgresHook:
         """Retrieve Airflow hook to interface with the Postgres database."""
         return PostgresHook(postgres_conn_id=self.conn_id)
 
@@ -110,3 +115,57 @@ class PostgresDatabase(BaseDatabase):
 
         inspector = sqlalchemy.inspect(self.sqlalchemy_engine)
         return bool(inspector.dialect.has_table(self.connection, table.name, schema))
+
+    def merge_table(
+        self,
+        source_table: Table,
+        target_table: Table,
+        source_to_target_columns_map: Dict[str, str],
+        target_conflict_columns: List[str],
+        if_conflicts: MergeConflictStrategy = "exception",
+    ) -> None:
+        """
+        Merge the source table rows into a destination table.
+        The argument `if_conflicts` allows the user to define how to handle conflicts.
+
+        :param source_table: Contains the rows to be merged to the target_table
+        :param target_table: Contains the destination table in which the rows will be merged
+        :param source_to_target_columns_map: Dict of target_table columns names to source_table columns names
+        :param target_conflict_columns: List of cols where we expect to have a conflict while combining
+        :param if_conflicts: The strategy to be applied if there are conflicts.
+        """
+
+        def identifier_args(table: Table):
+            schema = table.metadata.schema
+            return (schema, table.name) if schema else (table.name,)
+
+        statement = "INSERT INTO {target_table} ({target_columns}) SELECT {source_columns} FROM {source_table}"
+
+        source_columns = list(source_to_target_columns_map.keys())
+        target_columns = list(source_to_target_columns_map.values())
+
+        if if_conflicts == "ignore":
+            statement += " ON CONFLICT ({target_conflict_columns}) DO NOTHING"
+        elif if_conflicts == "update":
+            statement += " ON CONFLICT ({target_conflict_columns}) DO UPDATE SET {update_statements}"
+
+        source_column_names = [postgres_sql.Identifier(col) for col in source_columns]
+        target_column_names = [postgres_sql.Identifier(col) for col in target_columns]
+        update_statements = [
+            postgres_sql.SQL("{col_name}=EXCLUDED.{col_name}").format(col_name=col_name)
+            for col_name in target_column_names
+        ]
+
+        query = postgres_sql.SQL(statement).format(
+            target_columns=postgres_sql.SQL(",").join(target_column_names),
+            target_table=postgres_sql.Identifier(*identifier_args(target_table)),
+            source_columns=postgres_sql.SQL(",").join(source_column_names),
+            source_table=postgres_sql.Identifier(*identifier_args(source_table)),
+            update_statements=postgres_sql.SQL(",").join(update_statements),
+            target_conflict_columns=postgres_sql.SQL(",").join(
+                [postgres_sql.Identifier(x) for x in target_conflict_columns]
+            ),
+        )
+
+        sql = query.as_string(self.hook.get_conn())
+        self.run_sql(sql_statement=sql)
