@@ -2,9 +2,10 @@ import os
 from typing import Dict, List, Tuple
 from urllib.parse import urlparse, urlunparse
 
+from airflow.providers.amazon.aws.hooks.s3 import S3Hook
+
 from astro.constants import FileLocation
 from astro.files.locations.base import BaseFileLocation
-from astro.utils.dependencies import s3
 
 
 class S3Location(BaseFileLocation):
@@ -22,7 +23,7 @@ class S3Location(BaseFileLocation):
         """Structure s3fs credentials from Airflow connection.
         s3fs enables pandas to write to s3
         """
-        hook = s3.S3Hook(aws_conn_id=self.conn_id) if self.conn_id else s3.S3Hook()
+        hook = S3Hook(aws_conn_id=self.conn_id) if self.conn_id else S3Hook()
         session = hook.get_session()
         return {"client": session.client("s3")}
 
@@ -32,7 +33,7 @@ class S3Location(BaseFileLocation):
         url = urlparse(self.path)
         bucket_name = url.netloc
         prefix = url.path[1:]
-        hook = s3.S3Hook(aws_conn_id=self.conn_id) if self.conn_id else s3.S3Hook()
+        hook = S3Hook(aws_conn_id=self.conn_id) if self.conn_id else S3Hook()
         prefixes = hook.list_keys(bucket_name=bucket_name, prefix=prefix)
         paths = [
             urlunparse((url.scheme, url.netloc, keys, "", "", "")) for keys in prefixes
